Region

Enum Region 

#[repr(u8)]
pub enum Region { China900 = 1, Us = 2, Europe = 3, China800 = 4, Korea = 6, }
Operating region for the reader

Variants



China900 = 1

China 900 MHz band



Us = 2

US band



Europe = 3

Europe band



China800 = 4

China 800 MHz band



Korea = 6

South Korea band

Implementations

Source

impl Region

pub fn base_frequency(&self) -> f64

Get the base frequency for this region in MHz

pub fn channel_spacing(&self) -> f64

Get the channel spacing for this region in MHz

pub fn channel_from_frequency(&self, freq_mhz: f64) -> u8

Calculate channel index from frequency

pub fn frequency_from_channel(&self, channel: u8) -> f64

Calculate frequency from channel index